import os
#defines absolute path and the api token file name
here = os.path.abspath(os.path.dirname(__file__))
token_path = os.path.join(here, 'api_token.txt')

def apiToken(token_path):
    api_token = input('''
Use of this library requires obtaining an API Key from
The Maricopa County Assessor's Office. This can be done by
visiting https://preview.mcassessor.maricopa.gov/contact/
and filling out the form.

Change the "Subject" Field to "API Token/Question",
provide your name, number, and a brief note. Then click
"Send Message". MCA's web developer will send you an email
shortly after with the API Key. You can hit CTRL-C to exit.

If you already have a key, please enter it here:
    ''')

    with open(token_path, 'w') as file:
        file.write(api_token)
        file.close()

    print(f'''
    ============================================

    Your key has been set to:

    {api_token}

    ============================================
    ''')
    return api_token

#print('APItoken.py CWD: ', os.getcwd())
if os.path.isfile(token_path) == True:
    with open(token_path, 'r') as file:
        API_TOKEN = file.read().strip()
else:
    API_TOKEN = apiToken(token_path)
    #print(API_TOKEN)

#         if API_TOKEN == '':
#             MCA_API_TKN = API_TOKEN
#             print('''
# instructions to call the method again
#             ''')
#         else:
#             MCA_API_TKN = API_TOKEN

    #print('api_token.txt isfile: False')



try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup


import os

readme = ""
here = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(here, "readme.md")
if os.path.exists(readme_path):
    with open(readme_path, "rb") as stream:
        readme = stream.read().decode("utf8")

setup(
    long_description=readme,
    name="mcaapi",
    version="0.0.4",
    description="A Python wrapper for the Maricopa County Assessor API.",
    python_requires="==3.*",
    project_urls={"repository": "https://github.com/foxbatcs/mcaapi"},
    author="foxbatcs",
    author_email="fbcs@foxbatcs.com",
    license="MIT",
    packages=[
        "mcaapi"
    ],
    package_dir={"": "."},
    package_data={},
    install_requires= find_packages(),
    extras_require={
        "dev": [
            "wheel==0.*,>=0.30.0"
        ],
    },
)
